.. _halo-analysis:

Halo Analysis
=============

This section covers finding and analyzing halos using the
:class:`~yt_astro_analysis.halo_analysis.halo_catalog.halo_catalog.HaloCatalog`.
If you already have halo catalogs and simply want to load them into yt, see
:ref:`halo-catalog-data`.

.. toctree::
   :maxdepth: 2

   halo_finding
   halo_catalog
   halo_plot_callbacks
   halo_merger_tree
